@@ -1,11 +1,11 @@
-# ReplaceSupport 1.0.2
-# (c) 2000-2004, Stefan H. Holek, stefan@epy.co.at
+# ReplaceSupport 1.0.3
+# (c) 2000-2005, Stefan H. Holek, stefan@epy.co.at
 # http://zope.org/Members/shh/ReplaceSupport
 # License: ZPL
-# Zope: 2.3-2.7
+# Zope: 2.6-2.8
 
 __doc__ = 'Add a Replace tab to Folders'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 
 __refresh_module__ = 0
 
@@ -19,12 +19,12 @@ try:
     FindSupport.manage_options = FindSupport.manage_options + ReplaceSupport.manage_options
     FindSupport.manage_replaceForm = ReplaceSupport.manage_replaceForm
     FindSupport.manage_replaceResult = ReplaceSupport.manage_replaceResult 
-    FindSupport.ZopeReplace = ReplaceSupport.ZopeReplace
-    FindSupport.PrincipiaReplace = ReplaceSupport.ZopeReplace
-    FindSupport._ZopeReplace = ReplaceSupport._ZopeReplace
-    FindSupport._PrincipiaReplace = ReplaceSupport._ZopeReplace
+    FindSupport.ZopeReplace = ReplaceSupport.ZopeReplace.im_func
+    FindSupport.PrincipiaReplace = ReplaceSupport.ZopeReplace.im_func
+    FindSupport._ZopeReplace = ReplaceSupport._ZopeReplace.im_func
+    FindSupport._PrincipiaReplace = ReplaceSupport._ZopeReplace.im_func
     FindSupport._ReplaceHandlerRegistry = ReplaceSupport._ReplaceHandlerRegistry
-    FindSupport.getReplaceHandlerMetaTypes = ReplaceSupport.getReplaceHandlerMetaTypes
+    FindSupport.getReplaceHandlerMetaTypes = ReplaceSupport.getReplaceHandlerMetaTypes.im_func
 
     default__class_init__(FindSupport)
 
