@@ -152,8 +152,12 @@ class ReplaceSupport(ExtensionClass.Base):
                 and
                 (not obj_searchterm or
                  (hasattr(ob, 'PrincipiaSearchSource') and
-                  find(ob.PrincipiaSearchSource(), obj_searchterm) >= 0
-                  ))
+                  find(ob.PrincipiaSearchSource(), obj_searchterm) >= 0)
+                 # http://zope.org/Collectors/Zope/1317
+                 or
+                 (hasattr(ob, 'SearchableText') and
+                  find(ob.SearchableText(), obj_searchterm) >= 0)
+                )
                 and
                 (not obj_expr or expr_match(ob, obj_expr))
                 and
@@ -166,7 +170,7 @@ class ReplaceSupport(ExtensionClass.Base):
 		# Find and apply a handler for this object
 		handler = self._ReplaceHandlerRegistry.getHandler(ob.meta_type)
 		if handler and (not check_change_permission or \
-                    getSecurityManager().checkPermission(handler.getChangePermission(), ob)):
+                   getSecurityManager().checkPermission(handler.getChangePermission(), ob)):
                     body = replace(handler.getBody(ob), obj_searchterm, obj_replaceterm)
                     params = replace(handler.getParams(ob), obj_searchterm, obj_replaceterm)	
                     handler.manageEdit(ob, body, params)
