@@ -1,11 +1,11 @@
-# ReplaceSupport 1.0.2
-# (c) 2000-2004, Stefan H. Holek, stefan@epy.co.at
+# ReplaceSupport 1.0.3
+# (c) 2000-2005, Stefan H. Holek, stefan@epy.co.at
 # http://zope.org/Members/shh/ReplaceSupport
 # License: ZPL
-# Zope: 2.3-2.7
+# Zope: 2.6-2.8
 
 __doc__ = 'Add a Replace tab to Folders'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 
 __refresh_module__ = 0
 
@@ -19,12 +19,12 @@ try:
     Folder.manage_options = Folder.manage_options + ReplaceSupport.manage_options
     Folder.manage_replaceForm = ReplaceSupport.manage_replaceForm
     Folder.manage_replaceResult = ReplaceSupport.manage_replaceResult 
-    Folder.ZopeReplace = ReplaceSupport.ZopeReplace
-    Folder.PrincipiaReplace = ReplaceSupport.ZopeReplace
-    Folder._ZopeReplace = ReplaceSupport._ZopeReplace
-    Folder._PrincipiaReplace = ReplaceSupport._ZopeReplace
+    Folder.ZopeReplace = ReplaceSupport.ZopeReplace.im_func
+    Folder.PrincipiaReplace = ReplaceSupport.ZopeReplace.im_func
+    Folder._ZopeReplace = ReplaceSupport._ZopeReplace.im_func
+    Folder._PrincipiaReplace = ReplaceSupport._ZopeReplace.im_func
     Folder._ReplaceHandlerRegistry = ReplaceSupport._ReplaceHandlerRegistry
-    Folder.getReplaceHandlerMetaTypes = ReplaceSupport.getReplaceHandlerMetaTypes
+    Folder.getReplaceHandlerMetaTypes = ReplaceSupport.getReplaceHandlerMetaTypes.im_func
     
     default__class_init__(Folder)
 
